[![codecov](https://codecov.io/gh/grburgess/gbmgeometry/branch/master/graph/badge.svg)](https://codecov.io/gh/grburgess/gbmgeometry)
[![PyPi Downloads](http://pepy.tech/badge/gbmgeometry)](http://pepy.tech/project/gbmgeometry)
[![PyPI version fury.io](https://badge.fury.io/py/gbmgeometry.svg)](https://pypi.python.org/pypi/gbmgeometry/)
[![Documentation Status](https://readthedocs.org/projects/gbmgeometry/badge/?version=latest)](https://gbmgeometry.readthedocs.io/?badge=latest)
![GitHub contributors](https://img.shields.io/github/contributors/grburgess/gbmgeometry)


# gbmgeometry
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3749504.svg)](https://doi.org/10.5281/zenodo.3749504)
![alt text](https://raw.githubusercontent.com/grburgess/gbmgeometry/master/logo.png)

Routines to handle GBM geometry and plotting. 
* provides the ability to plot Fermi's orbit
* enables the reading and interpretation of GBM spacecraft files 
* computes GRB emission blockage by components of the spacecraft

Special thanks to [Bjoern Biltzinger](https://github.com/BjoernBiltzinger) and [Francesco Berlato](https://github.com/fberlato) for helping me with crazy geometry in multiple coordinate systems.

## Install

```bash
$> pip install gbmgeometry
```
